@@ -390,6 +390,7 @@ service BasicController {
     rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
     rpc MixParam(CustomMixParamForListRequest) returns (BasicMixParamListResponse) {}
     rpc MixParamWithSerializer(BasicParamWithSerializerListRequest) returns (BasicMixParamWithSerializerListResponse) {}
+    rpc TestBaseProtoSerializer(BaseProtoExampleRequest) returns (BaseProtoExampleListResponse) {}
 }
 
 message BasicFetchDataForUserRequest {
@@ -400,6 +401,7 @@ message BasicServiceResponse {
     string user_name = 1;
     google.protobuf.Struct user_data = 2;
     bytes bytes_example = 3;
+    repeated google.protobuf.Struct list_of_dict = 4;
 }
 
 message BasicServiceListResponse {
@@ -438,6 +440,7 @@ message BasicParamWithSerializerRequest {
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
+    repeated google.protobuf.Struct list_of_dict = 5;
 }
 
 message BasicParamWithSerializerListRequest {
@@ -450,6 +453,23 @@ message BasicMixParamWithSerializerListResponse {
     int32 count = 2;
 }
 
+message BaseProtoExampleRequest {
+    string uuid = 1;
+    int32 number_of_elements = 2;
+    bool is_archived = 3;
+}
+
+message BaseProtoExampleResponse {
+    string uuid = 1;
+    int32 number_of_elements = 2;
+    bool is_archived = 3;
+}
+
+message BaseProtoExampleListResponse {
+    repeated BaseProtoExampleResponse results = 1;
+    int32 count = 2;
+}
+
 """
 
 
@@ -495,6 +515,7 @@ service BasicController {
     rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
     rpc MixParam(CustomMixParamForRequestList) returns (BasicMixParamListResponse) {}
     rpc MixParamWithSerializer(BasicParamWithSerializerRequestList) returns (BasicMixParamWithSerializerListResponse) {}
+    rpc TestBaseProtoSerializer(BaseProtoExample) returns (BaseProtoExampleListResponse) {}
 }
 
 service ForeignModelController {
@@ -553,6 +574,7 @@ message BasicService {
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
+    repeated google.protobuf.Struct list_of_dict = 5;
 }
 
 message BasicServiceListResponse {
@@ -591,6 +613,7 @@ message BasicParamWithSerializerRequest {
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
+    repeated google.protobuf.Struct list_of_dict = 5;
 }
 
 message BasicParamWithSerializerRequestList {
@@ -603,6 +626,17 @@ message BasicMixParamWithSerializerListResponse {
     int32 count = 2;
 }
 
+message BaseProtoExample {
+    string uuid = 1;
+    int32 number_of_elements = 2;
+    bool is_archived = 3;
+}
+
+message BaseProtoExampleListResponse {
+    repeated BaseProtoExample results = 1;
+    int32 count = 2;
+}
+
 message ForeignModel {
     string uuid = 1;
     string name = 2;
@@ -746,6 +780,7 @@ service BasicController {
     rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
     rpc MixParam(CustomMixParamForListRequest) returns (BasicMixParamListResponse) {}
     rpc MixParamWithSerializer(BasicParamWithSerializerListRequest) returns (BasicMixParamWithSerializerListResponse) {}
+    rpc TestBaseProtoSerializer(BaseProtoExampleRequest) returns (BaseProtoExampleListResponse) {}
 }
 
 service ForeignModelController {
@@ -803,6 +838,7 @@ message BasicServiceResponse {
     string user_name = 1;
     google.protobuf.Struct user_data = 2;
     bytes bytes_example = 3;
+    repeated google.protobuf.Struct list_of_dict = 4;
 }
 
 message BasicServiceListResponse {
@@ -841,6 +877,7 @@ message BasicParamWithSerializerRequest {
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
     bytes bytes_example = 4;
+    repeated google.protobuf.Struct list_of_dict = 5;
 }
 
 message BasicParamWithSerializerListRequest {
@@ -853,6 +890,23 @@ message BasicMixParamWithSerializerListResponse {
     int32 count = 2;
 }
 
+message BaseProtoExampleRequest {
+    string uuid = 1;
+    int32 number_of_elements = 2;
+    bool is_archived = 3;
+}
+
+message BaseProtoExampleResponse {
+    string uuid = 1;
+    int32 number_of_elements = 2;
+    bool is_archived = 3;
+}
+
+message BaseProtoExampleListResponse {
+    repeated BaseProtoExampleResponse results = 1;
+    int32 count = 2;
+}
+
 message ForeignModelResponse {
     string uuid = 1;
     string name = 2;
